
package Google::Ads::AdWords::v201402::TypeMaps::AdGroupFeedService;
use strict;
use warnings;

our $typemap_1 = {
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/reason' => 'Google::Ads::AdWords::v201402::EntityNotFound::Reason',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/existingCount' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/status' => 'Google::Ads::AdWords::v201402::AdGroupFeed::Status',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/reason' => 'Google::Ads::AdWords::v201402::NotEmptyError::Reason',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'getResponse/rval/entries/matchingFunction/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/reason' => 'Google::Ads::AdWords::v201402::RateExceededError::Reason',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/matchingFunction' => 'Google::Ads::AdWords::v201402::Function',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/reason' => 'Google::Ads::AdWords::v201402::AuthorizationError::Reason',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/limit' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'getResponse/rval/entries' => 'Google::Ads::AdWords::v201402::AdGroupFeed',
               'mutateResponse/rval/value/status' => 'Google::Ads::AdWords::v201402::AdGroupFeed::Status',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/placeholderTypes' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'ApiExceptionFault/errors/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/accountLimitType' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/paging/numberResults' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/reason' => 'Google::Ads::AdWords::v201402::CollectionSizeError::Reason',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]' => 'Google::Ads::AdWords::v201402::OperationAccessDenied',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'Fault/detail/ApiExceptionFault/errors[QueryError]' => 'Google::Ads::AdWords::v201402::QueryError',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]' => 'Google::Ads::AdWords::v201402::RateExceededError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector/ordering/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/matchingFunction/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/faultstring' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]' => 'Google::Ads::AdWords::v201402::EntityCountLimitExceeded',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/reason' => 'Google::Ads::AdWords::v201402::QuotaCheckError::Reason',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/reason' => 'Google::Ads::AdWords::v201402::DatabaseError::Reason',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/reason' => 'Google::Ads::AdWords::v201402::ClientTermsError::Reason',
               'get/selector/ordering/sortOrder' => 'Google::Ads::AdWords::v201402::SortOrder',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]' => 'Google::Ads::AdWords::v201402::InternalApiError',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'queryResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'get/selector/predicates/operator' => 'Google::Ads::AdWords::v201402::Predicate::Operator',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction' => 'Google::Ads::AdWords::v201402::Function',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'getResponse' => 'Google::Ads::AdWords::v201402::AdGroupFeedService::getResponse',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'Fault/detail/ApiExceptionFault/errors[IdError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval' => 'Google::Ads::AdWords::v201402::AdGroupFeedPage',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]' => 'Google::Ads::AdWords::v201402::ClientTermsError',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/matchingFunction/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ClientTermsError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries' => 'Google::Ads::AdWords::v201402::AdGroupFeed',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/reason' => 'Google::Ads::AdWords::v201402::InternalApiError::Reason',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/reason' => 'Google::Ads::AdWords::v201402::RejectedError::Reason',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/reason' => 'Google::Ads::AdWords::v201402::SelectorError::Reason',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]' => 'Google::Ads::AdWords::v201402::DatabaseError',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]' => 'Google::Ads::AdWords::v201402::AuthorizationError',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'get/selector/paging' => 'Google::Ads::AdWords::v201402::Paging',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutate/operations/operator' => 'Google::Ads::AdWords::v201402::Operator',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'Fault/detail/ApiExceptionFault/errors[FunctionError]' => 'Google::Ads::AdWords::v201402::FunctionError',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'query' => 'Google::Ads::AdWords::v201402::AdGroupFeedService::query',
               'getResponse/rval/entries/matchingFunction/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]' => 'Google::Ads::AdWords::v201402::SizeLimitError',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/faultcode' => 'SOAP::WSDL::XSD::Typelib::Builtin::anyURI',
               'getResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse' => 'Google::Ads::AdWords::v201402::AdGroupFeedService::queryResponse',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[FunctionError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]/reason' => 'Google::Ads::AdWords::v201402::AdGroupFeedError::Reason',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/status' => 'Google::Ads::AdWords::v201402::AdGroupFeed::Status',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail' => 'Google::Ads::AdWords::FaultDetail',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/matchingFunction/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/message' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'getResponse/rval/entries/matchingFunction/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]' => 'Google::Ads::AdWords::v201402::CollectionSizeError',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/dateRange' => 'Google::Ads::AdWords::v201402::DateRange',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/reason' => 'Google::Ads::AdWords::v201402::RangeError::Reason',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]' => 'Google::Ads::AdWords::v201402::ReadOnlyError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]' => 'Google::Ads::AdWords::v201402::RequestError',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]' => 'Google::Ads::AdWords::v201402::RequiredError',
               'getResponse/rval/entries/placeholderTypes' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/matchingFunction/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]' => 'Google::Ads::AdWords::v201402::NotEmptyError',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]' => 'Google::Ads::AdWords::v201402::AuthenticationError',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'mutate/operations/operand/matchingFunction/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/matchingFunction/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get/selector' => 'Google::Ads::AdWords::v201402::Selector',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/Page.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'mutateResponse/rval/value/placeholderTypes' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/reason' => 'Google::Ads::AdWords::v201402::AuthenticationError::Reason',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/Operation.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateScope' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/reason' => 'Google::Ads::AdWords::v201402::StringLengthError::Reason',
               'get/selector/predicates/field' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse' => 'Google::Ads::AdWords::v201402::AdGroupFeedService::mutateResponse',
               'mutate/operations/operand/matchingFunction/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/selector/predicates' => 'Google::Ads::AdWords::v201402::Predicate',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'mutateResponse/rval/value/matchingFunction/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/reason' => 'Google::Ads::AdWords::v201402::EntityCountLimitExceeded::Reason',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'get/selector/fields' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NullError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'get' => 'Google::Ads::AdWords::v201402::AdGroupFeedService::get',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault' => 'SOAP::WSDL::SOAP::Typelib::Fault11',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]' => 'Google::Ads::AdWords::v201402::QuotaCheckError',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'Fault/detail/ApiExceptionFault/errors[AuthenticationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'get/selector/dateRange/max' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'get/selector/paging/startIndex' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]' => 'Google::Ads::AdWords::v201402::StringLengthError',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityNotFound]' => 'Google::Ads::AdWords::v201402::EntityNotFound',
               'Fault/detail/ApiExceptionFault/errors[FunctionError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/reason' => 'Google::Ads::AdWords::v201402::QueryError::Reason',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/status' => 'Google::Ads::AdWords::v201402::AdGroupFeed::Status',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/reason' => 'Google::Ads::AdWords::v201402::DistinctError::Reason',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]' => 'Google::Ads::AdWords::v201402::NullError',
               'get/selector/predicates/values' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutate/operations/operand/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval' => 'Google::Ads::AdWords::v201402::AdGroupFeedPage',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/adGroupId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[FunctionError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'Fault/detail/ApiExceptionFault/errors[FunctionError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'mutateResponse/rval/value/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction' => 'Google::Ads::AdWords::v201402::Function',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'ApiExceptionFault/errors/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'get/selector/dateRange/min' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RangeError]' => 'Google::Ads::AdWords::v201402::RangeError',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/retryAfterSeconds' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[InternalApiError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutate/operations/operand/matchingFunction/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'Fault/detail/ApiExceptionFault/errors[AuthorizationError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/reason' => 'Google::Ads::AdWords::v201402::RequiredError::Reason',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[NullError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/ApplicationException.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'Fault/detail/ApiExceptionFault/errors[IdError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'Fault/detail/ApiExceptionFault/errors[DatabaseError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/reason' => 'Google::Ads::AdWords::v201402::ReadOnlyError::Reason',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction' => 'Google::Ads::AdWords::v201402::Function',
               'mutate/operations/operand/matchingFunction/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NullError]/reason' => 'Google::Ads::AdWords::v201402::NullError::Reason',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]/reason' => 'Google::Ads::AdWords::v201402::IdError::Reason',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/faultactor' => 'SOAP::WSDL::XSD::Typelib::Builtin::token',
               'ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate' => 'Google::Ads::AdWords::v201402::AdGroupFeedService::mutate',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QueryError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'Fault/detail/ApiExceptionFault/errors' => 'Google::Ads::AdWords::v201402::ApiError',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'Fault/detail/ApiExceptionFault/errors[NullError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'queryResponse/rval/entries/placeholderTypes' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutate/operations/operand/matchingFunction/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'get/selector/ordering' => 'Google::Ads::AdWords::v201402::OrderBy',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault' => 'Google::Ads::AdWords::v201402::ApiException',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[SizeLimitError]/reason' => 'Google::Ads::AdWords::v201402::SizeLimitError::Reason',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[QuotaCheckError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/ListReturnValue.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/fieldPath' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[DistinctError]' => 'Google::Ads::AdWords::v201402::DistinctError',
               'Fault/detail/ApiExceptionFault/errors[RequestError]/reason' => 'Google::Ads::AdWords::v201402::RequestError::Reason',
               'mutate/operations/operand/matchingFunction/lhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[ReadOnlyError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'Fault/detail/ApiExceptionFault/errors[RequiredError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[IdError]' => 'Google::Ads::AdWords::v201402::IdError',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RangeError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[StringLengthError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval' => 'Google::Ads::AdWords::v201402::AdGroupFeedReturnValue',
               'query/query' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'Fault/detail/ApiExceptionFault/errors[OperationAccessDenied]/reason' => 'Google::Ads::AdWords::v201402::OperationAccessDenied::Reason',
               'getResponse/rval/totalNumEntries' => 'SOAP::WSDL::XSD::Typelib::Builtin::int',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/type' => 'Google::Ads::AdWords::v201402::ConstantOperand::ConstantType',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]' => 'Google::Ads::AdWords::v201402::AdGroupFeedError',
               'Fault/detail/ApiExceptionFault/errors[EntityCountLimitExceeded]/enclosingId' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[NotEmptyError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedAttributeId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value' => 'Google::Ads::AdWords::v201402::AdGroupFeed',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value' => 'Google::Ads::AdWords::v201402::Function',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'Fault/detail/ApiExceptionFault/errors[RejectedError]' => 'Google::Ads::AdWords::v201402::RejectedError',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]' => 'Google::Ads::AdWords::v201402::RequestContextOperand',
               'mutateResponse/rval/value/matchingFunction/rhsOperand[FunctionOperand]/value/operator' => 'Google::Ads::AdWords::v201402::Function::Operator',
               'mutateResponse/rval/value/matchingFunction/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/lhsOperand[RequestContextOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'Fault/detail/ApiExceptionFault/errors[CollectionSizeError]/errorString' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/stringValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/lhsOperand[ConstantOperand]' => 'Google::Ads::AdWords::v201402::ConstantOperand',
               'mutateResponse/rval/value/matchingFunction/lhsOperand' => 'Google::Ads::AdWords::v201402::FunctionArgumentOperand',
               'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]/ApiError.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]' => 'Google::Ads::AdWords::v201402::FunctionOperand',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FeedAttributeOperand]' => 'Google::Ads::AdWords::v201402::FeedAttributeOperand',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[FunctionOperand]/value/rhsOperand[RequestContextOperand]/contextType' => 'Google::Ads::AdWords::v201402::RequestContextOperand::ContextType',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[AdGroupFeedError]/trigger' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand' => 'Google::Ads::AdWords::v201402::AdGroupFeed',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'getResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'Fault/detail/ApiExceptionFault/errors[RateExceededError]/rateName' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'mutate/operations/operand/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'queryResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[FeedAttributeOperand]/FunctionArgumentOperand.Type' => 'SOAP::WSDL::XSD::Typelib::Builtin::string',
               'getResponse/rval/entries/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/longValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutateResponse/rval/value/matchingFunction/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'Fault/detail/ApiExceptionFault/errors[FunctionError]/reason' => 'Google::Ads::AdWords::v201402::FunctionError::Reason',
               'Fault/detail/ApiExceptionFault/errors[SelectorError]' => 'Google::Ads::AdWords::v201402::SelectorError',
               'mutate/operations/operand/matchingFunction/rhsOperand[FunctionOperand]/value/lhsOperand[FunctionOperand]/value/lhsOperand[ConstantOperand]/doubleValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::double',
               'queryResponse/rval/entries/matchingFunction/lhsOperand[FunctionOperand]/value/rhsOperand[ConstantOperand]/booleanValue' => 'SOAP::WSDL::XSD::Typelib::Builtin::boolean',
               'getResponse/rval/entries/feedId' => 'SOAP::WSDL::XSD::Typelib::Builtin::long',
               'mutate/operations' => 'Google::Ads::AdWords::v201402::AdGroupFeedOperation'
             };
;

sub get_class {
  my $name = join '/', @{ $_[1] };
  return $typemap_1->{ $name };
}

sub get_typemap {
    return $typemap_1;
}

1;

__END__

__END__

=pod

=head1 NAME

Google::Ads::AdWords::v201402::TypeMaps::AdGroupFeedService - typemap for AdGroupFeedService

=head1 DESCRIPTION

Typemap created by SOAP::WSDL for map-based SOAP message parsers.

=cut

